"use client";

import { createContext, useContext, useEffect, useState } from "react";
import { remoteConfig, fetchAndActivate, getValue } from "../lib/firebase";

const ApiKeyContext = createContext<string | null>(null);

export const ApiKeyProvider = ({ children }: { children: React.ReactNode }) => {
  const [apiKey, setApiKey] = useState<string | null>(null);

  useEffect(() => {
    if (!remoteConfig) {
      console.warn("🚨 Remote Config is not available (running on server). Skipping fetch.");
      return; // ✅ Prevents crashes
    }

    const fetchConfig = async () => {
      try {
        // ✅ Type-safe check before calling Firebase functions
        if (!remoteConfig) return;
        await fetchAndActivate(remoteConfig);
        const fetchedApiKey = getValue(remoteConfig, "View").asString();
        setApiKey(fetchedApiKey || null);
      } catch (error) {
        console.error("🔥 Error fetching remote config:", error);
      }
    };

    fetchConfig();
  }, []);

  return <ApiKeyContext.Provider value={apiKey}>{children}</ApiKeyContext.Provider>;
};

export const useApiKey = () => {
  return useContext(ApiKeyContext);
};
